/*-
 * Copyright (c) 2017-2021 Carsten Sonne Larsen <cs@innolan.net>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#include <exec/ports.h>
#include <exec/nodes.h>
#include <exec/memory.h>
#include <proto/exec.h>
#include <stdarg.h>

#include "log.h"
#include "string.h"
#include "global.h"
#include "message.h"

static void VLogLine(enum LogSeverity level, const char *module, const char *format, va_list ap)
{
    struct LogMessage *message = (struct LogMessage *)AllocVec(sizeof(struct LogMessage), MEMF_ANY | MEMF_CLEAR);
    if (message == NULL)
        return;

    message->Severity = level;
    StrCopy(message->Module, module);
    VSNPrintf(message->Text, MAXLOGLINESIZE - 1, format, ap);
    SendLogMessage(message);
}

void LogMemTraceMsg(const char *module, const char *format, ...)
{
    va_list args;
    va_start(args, format);
    VLogLine(MemTraceMessage, module, format, args);
    va_end(args);
}

void LogDebugMsg(const char *module, const char *format, ...)
{
    va_list args;
    va_start(args, format);
    VLogLine(DebugMessage, module, format, args);
    va_end(args);
}

void LogTraceMsg(const char *module, const char *format, ...)
{
    va_list args;
    va_start(args, format);
    VLogLine(TraceMessage, module, format, args);
    va_end(args);
}

void LogInfoMsg(const char *module, const char *format, ...)
{
    va_list args;
    va_start(args, format);
    VLogLine(InfoMessage, module, format, args);
    va_end(args);
}

void LogNoticeMsg(const char *module, const char *format, ...)
{
    va_list args;
    va_start(args, format);
    VLogLine(NoticeMessage, module, format, args);
    va_end(args);
}

void LogWarnMsg(const char *module, const char *format, ...)
{
    va_list args;
    va_start(args, format);
    VLogLine(WarningMessage, module, format, args);
    va_end(args);
}

void LogErrorMsg(const char *module, const char *format, ...)
{
    va_list args;
    va_start(args, format);
    VLogLine(ErrorMessage, module, format, args);
    va_end(args);
}
