/*-
 * Copyright (c) 2017-2021 Carsten Sonne Larsen <cs@innolan.net>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#ifndef WIN_H_INCLUDED
#define WIN_H_INCLUDED

#include <proto/intuition.h>
#include <proto/gadtools.h>

#define GID_SERVER 1001
#define GID_PORT 1002
#define GID_TIMEOUT 1003
#define GID_INTERVAL 1004
#define GID_THRESHOLD 1005
#define GID_READONLY 1006
#define GID_PRIORITY 1007
#define GID_SAVE 1008
#define GID_USE 1009
#define GID_CANCEL 1010

struct AppSettingWindow
{
    struct Screen *Screen;
    struct Window *Window;
    struct Gadget *GadgetList;
    void *VisualInfo;
    char *PriorityText;
    char *ThresholdText;
    char *TimezoneText;
    long Width;
    long Height;
    struct AppSettingWindowGadgets *Gadgets;
};

/* win_main.c */
void ShowSettingWindow(void);

/* win_gad.c */
bool CreateGadgets(void);
void UseSettings(void);
void ReadUiServer(void);
void ReadUiPort(void);
void ReadUiTimeout(void);
void ReadUiInterval(void);
void ReadUiThreshold(void);
void ReadUiCxPriority(void);
void WriteUiServer(void);
void WriteUiPort(void);
void WriteUiTimeout(void);
void WriteUiInterval(void);
void WriteUiThreshold(void);
void WriteUiCxPriority(void);
void ShowLastSync(struct timeval *tv);
void SetDefaultSettings(void);
void ShowNewTimezone(void);

extern volatile bool WindowProcRunning;
extern struct AppSettings *WindowSettings;
extern struct AppSettingWindow SettingWindow;

#endif
